==> rapidtide-2.6.9.1.tar.gz: rapidtide-2.6.9.1/CODE_OF_CONDUCT.md <==
# Code of Conduct

In the interest of fostering an open and welcoming environment we want
participation in our project and our community to be a harassment-free
experience for everyone.

Although no list can hope to be all-encompassing, we explicitly honor diversity in age,
body size, disability, ethnicity, gender identity and expression, level of experience, native language, education, socio-economic status, nationality, personal appearance, race, religion,
or sexual identity and orientation.

## Our Standards

We aim to promote behavior that contributes to a positive and welcoming environment.
Examples of such behavior include:

* Using inclusive language
* Being respectful of differing viewpoints and experiences
* Showing empathy towards other community members

We do not tolerate harassment or other, inappropriate behavior in our community.
Examples of unacceptable behavior by participants include:

* The use of sexualized language or imagery and unwelcome sexual attention or
  advances
* Personal or political attacks on contributors, and insulting or derogatory
  comments on contributed code with the intent to undermine contributions
* Public or private harassment

## Our Responsibilities

The maintainers are responsible for clarifying the standards
of acceptable behavior and are expected to take appropriate and fair corrective
action in response to any instances of unacceptable behavior.

The maintainers have the right and responsibility to remove,
edit, or reject comments, commits, code, issues, and other contributions
that are not aligned to this Code of Conduct, or to ban temporarily or
permanently any contributor for other behaviors that they deem inappropriate,
threatening, offensive, or harmful.

## Scope

This Code of Conduct applies both within our online GitHub repository
and in public spaces when an individual is representing the project or its community.
Examples of representing a project or community include using an official project e-mail
address, posting via an official social media account, or acting as an appointed
representative at an online or offline event.

## Enforcement

Instances of abusive, harassing, or otherwise unacceptable behavior may be
reported by contacting Blaise Frederick at bbfrederick@mclean.harvard.edu.
Confidentiality will be respected in reporting.

## Attribution

This Code of Conduct is adapted from the [Contributor Covenant][homepage], version 1.4,
available at https://www.contributor-covenant.org/version/1/4/code-of-conduct.html

[homepage]: https://www.contributor-covenant.org

==> rapidtide-3.0.1.tar.gz: rapidtide-3.0.1/CODE_OF_CONDUCT.md <==
# Code of Conduct

In the interest of fostering an open and welcoming environment we want
participation in our project and our community to be a harassment-free
experience for everyone.

Although no list can hope to be all-encompassing, we explicitly honor diversity in age,
body size, disability, ethnicity, gender identity and expression, level of experience, native language, education, socioeconomic status, nationality, personal appearance, race, religion,
or sexual identity and orientation.

## Our Standards

We aim to promote behavior that contributes to a positive and welcoming environment.
Examples of such behavior include:

* Using inclusive language
* Being respectful of differing viewpoints and experiences
* Showing empathy towards other community members

We do not tolerate harassment or other, inappropriate behavior in our community.
Examples of unacceptable behavior by participants include:

* The use of sexualized language or imagery and unwelcome sexual attention or
  advances
* Personal or political attacks on contributors, and insulting or derogatory
  comments on contributed code with the intent to undermine contributions
* Public or private harassment

## Our Responsibilities

The maintainers are responsible for clarifying the standards
of acceptable behavior and are expected to take appropriate and fair corrective
action in response to any instances of unacceptable behavior.

The maintainers have the right and responsibility to remove,
edit, or reject comments, commits, code, issues, and other contributions
that are not aligned to this Code of Conduct, or to ban temporarily or
permanently any contributor for other behaviors that they deem inappropriate,
threatening, offensive, or harmful.

## Scope

This Code of Conduct applies both within our online GitHub repository
and in public spaces when an individual is representing the project or its community.
Examples of representing a project or community include using an official project e-mail
address, posting via an official social media account, or acting as an appointed
representative at an online or offline event.

## Enforcement

Instances of abusive, harassing, or otherwise unacceptable behavior may be
reported by contacting Blaise Frederick at bbfrederick@mclean.harvard.edu.
Confidentiality will be respected in reporting.

## Attribution

This Code of Conduct is adapted from the [Contributor Covenant][homepage], version 1.4,
available at https://www.contributor-covenant.org/version/1/4/code-of-conduct.html

[homepage]: https://www.contributor-covenant.org
